@@ -1,4 +1,4 @@
-import {Record, List, Map, fromJS} from 'immutable';
+import {Record, List, Map, fromJS, Seq} from 'immutable';
 import {MODE_IDLE} from './constants';
 
 let safeLoadMapList = (mapList, Model, defaultMap) => {
@@ -204,6 +204,61 @@ export class Scene extends Record({
   }
 }
 
+export class CatalogElement extends Record({
+  name: "",
+  prototype: "",
+  info: new Map(),
+  properties: new Map(),
+}, 'CatalogElement') {
+  constructor(json = {}) {
+    super({
+      ...json,
+      info: fromJS(json.info),
+      properties: fromJS(json.properties)
+    });
+  }
+}
+
+export class Catalog extends Record({
+  elements: new Map(),
+}, 'Catalog') {
+  constructor(json = {}) {
+    super({
+      elements: safeLoadMapList(json.elements, CatalogElement)
+    })
+  }
+
+  factoryElement(type, options, initialProperties = {}) {
+    if(!this.elements.has(type)){
+      let catList = this.elements.map(element => element.name).toArray();
+      throw new Error(`Element ${type} does not exist in catalog ${catList}`);
+    }
+
+    let element = this.elements.get(type);
+
+    initialProperties = new Map(initialProperties);
+
+    let properties = element.properties
+      .map((value, key) => initialProperties.has(key) ? initialProperties.get(key) : value.get('defaultValue'));
+
+    switch (element.prototype) {
+      case 'lines':
+        return new Line(options).merge({properties});
+
+      case 'holes':
+        return new Hole(options).merge({properties});
+
+      case 'areas':
+        return new Area(options).merge({properties});
+
+      case 'items':
+        return new Item(options).merge({properties});
+
+      default:
+        throw new Error('prototype not valid');
+    }
+  }
+}
 
 export class State extends Record({
   mode: MODE_IDLE,
@@ -211,6 +266,8 @@ export class State extends Record({
   scene: new Scene(),
   sceneHistory: new List([new Scene()]),
 
+  catalog: new Catalog(),
+
   viewer2D: new Map(),
 
   snapElements: new List(),
@@ -229,6 +286,8 @@ export class State extends Record({
       scene,
       sceneHistory: json.sceneHistory ? json.sceneHistory : new List([scene]),
 
+      catalog: new Catalog(json.catalog || {}),
+
       viewer2D: new Map(json.viewer2D || {}),
 
       drawingSupport: new Map(json.drawingSupport || {}),
@@ -240,3 +299,5 @@ export class State extends Record({
   }
 }
 
+
+
