@@ -13,10 +13,11 @@ import {
   UNDO,
   ROLLBACK,
   SET_PROJECT_PROPERTIES,
-  OPEN_PROJECT_CONFIGURATOR
+  OPEN_PROJECT_CONFIGURATOR,
+  INIT_CATALOG
 } from '../constants';
 
-import {State, Scene, Guide} from "../models";
+import {State, Scene, Guide, Catalog} from "../models";
 
 import {
   removeLine,
@@ -36,10 +37,10 @@ export default function (state, action) {
   switch (action.type) {
 
     case NEW_PROJECT:
-      return new State();
+      return newProject(state);
 
     case LOAD_PROJECT:
-      return loadProject(state, action.data, action.catalog);
+      return loadProject(state, action.sceneJSON);
 
     case OPEN_CATALOG:
       return openCatalog(state);
@@ -54,7 +55,7 @@ export default function (state, action) {
       return setProperties(state, action.properties);
 
     case REMOVE:
-      return remove(state, action.catalog);
+      return remove(state);
 
     case UNDO:
       return undo(state);
@@ -68,6 +69,9 @@ export default function (state, action) {
     case OPEN_PROJECT_CONFIGURATOR:
       return openProjectConfigurator(state);
 
+    case INIT_CATALOG:
+      return initCatalog(state, action.catalog);
+
     default:
       return state;
 
@@ -79,8 +83,12 @@ function openCatalog(state) {
     .set('mode', MODE_VIEWING_CATALOG);
 }
 
-function loadProject(state, data, catalog) {
-  return new State({scene: data});
+function newProject(state) {
+  return new State({catalog: state.catalog.toJS()});
+}
+
+function loadProject(state, sceneJSON) {
+  return new State({scene: sceneJSON, catalog: state.catalog.toJS()});
 }
 
 
@@ -104,8 +112,9 @@ function unselectAll(state) {
   })
 }
 
-function remove(state, catalog) {
+function remove(state) {
   let scene = state.scene;
+  let catalog = state.catalog;
 
   scene = scene.updateIn(['layers', scene.selectedLayer], layer => layer.withMutations(layer => {
     let {lines: selectedLines, holes: selectedHoles, items: selectedItems} = layer.selected;
@@ -179,3 +188,7 @@ function openProjectConfigurator(state) {
     mode: MODE_CONFIGURING_PROJECT,
   });
 }
+
+function initCatalog(state, catalog){
+  return state.set('catalog', new Catalog(catalog));
+}
