@@ -17,7 +17,7 @@ export function addLine(layer, type, x0, y0, x1, y1, catalog, properties = {}) {
     ({layer, vertex: v0} = addVertex(layer, x0, y0, 'lines', lineID));
     ({layer, vertex: v1} = addVertex(layer, x1, y1, 'lines', lineID));
 
-    line = catalog.createElement(type, {
+    line = catalog.factoryElement(type, {
       id: lineID,
       vertices: new List([v0.id, v1.id]),
       type
@@ -118,27 +118,28 @@ export function addLineAvoidingIntersections(layer, type, x0, y0, x1, y1, catalo
     lines.forEach(line => {
       let [v0, v1] = line.vertices.map(vertexID => vertices.get(vertexID)).toArray();
 
-      if (
-        !(Geometry.samePoints(v0, {x: x0, y: y0})
+      let hasCommonEndpoint =
+        (Geometry.samePoints(v0, {x: x0, y: y0})
         || Geometry.samePoints(v0, {x: x1, y: y1})
         || Geometry.samePoints(v1, {x: x0, y: y0})
-        || Geometry.samePoints(v1, {x: x1, y: y1}))) {
+        || Geometry.samePoints(v1, {x: x1, y: y1}));
 
-        let intersection = Geometry.intersectionFromTwoLineSegment(
-          {x: x0, y: y0}, {x: x1, y: y1},
-          v0, v1
-        );
 
-        if (intersection.type === "colinear") {
-          removeLine(layer, line.id);
-          points.push(v0, v1);
-        }
+      let intersection = Geometry.intersectionFromTwoLineSegment(
+        {x: x0, y: y0}, {x: x1, y: y1},
+        v0, v1
+      );
 
-        if (intersection.type === "intersecting") {
-          splitLine(layer, line.id, intersection.point.x, intersection.point.y, catalog);
-          points.push(intersection.point);
-        }
+      if (intersection.type === "colinear") {
+        removeLine(layer, line.id);
+        points.push(v0, v1);
       }
+
+      if (intersection.type === "intersecting" && (!hasCommonEndpoint)) {
+        splitLine(layer, line.id, intersection.point.x, intersection.point.y, catalog);
+        points.push(intersection.point);
+      }
+
     });
     addLinesFromPoints(layer, type, points, catalog);
   });
@@ -281,7 +282,7 @@ export function addArea(layer, type, verticesCoords, catalog) {
       vertices.push(vertex.id);
     });
 
-    area = catalog.createElement(type, {
+    area = catalog.factoryElement(type, {
       id: areaID,
       type,
       prototype: "areas",
@@ -364,7 +365,7 @@ export function addHole(layer, type, lineID, offset, catalog, properties = {}) {
   layer = layer.withMutations(layer => {
     let holeID = IDBroker.acquireID();
 
-    hole = catalog.createElement(type, {
+    hole = catalog.factoryElement(type, {
       id: holeID,
       type,
       offset,
@@ -399,7 +400,7 @@ export function addItem(layer, type, x, y, width, height, rotation, catalog) {
   layer = layer.withMutations(layer => {
     let itemID = IDBroker.acquireID();
 
-    item = catalog.createElement(type, {
+    item = catalog.factoryElement(type, {
       id: itemID,
       type,
       height,
